@@ -31,7 +31,7 @@ import codecs
 if sys.version_info[0] == 2:
     sys.stdout = codecs.getwriter('utf-8')(sys.stdout)
 
-__VERSION__ = '0.5.0'
+__VERSION__ = '0.5.1'
 
 DESCRIPTION = 'bumpversion: v{} (using Python v{})'.format(
     __VERSION__,
@@ -137,10 +137,7 @@ class Git(BaseVCS):
 
         info["commit_sha"] = describe_out.pop().lstrip("g")
         info["distance_to_latest_tag"] = int(describe_out.pop())
-        info["current_version"] = describe_out.pop().lstrip("v")
-
-        # assert type(info["current_version"]) == str
-        assert 0 == len(describe_out)
+        info["current_version"] = "-".join(describe_out).lstrip("v")
 
         return info
 
@@ -215,10 +212,20 @@ class ConfiguredFile(object):
 
     def contains(self, search):
         with io.open(self.path, 'rb') as f:
+            search_lines = search.splitlines()
+            lookbehind = []
+
             for lineno, line in enumerate(f.readlines()):
-                if search in line.decode('utf-8'):
+                lookbehind.append(line.decode('utf-8').rstrip("\n"))
+
+                if len(lookbehind) > len(search_lines):
+                    lookbehind = lookbehind[1:]
+
+                if (search_lines[0] in lookbehind[0] and
+                   search_lines[-1] in lookbehind[-1] and
+                   search_lines[1:-1] == lookbehind[1:-1]):
                     logger.info("Found '{}' in {} at line {}: {}".format(
-                        search, self.path, lineno, line.decode('utf-8').rstrip()))
+                        search, self.path, lineno - (len(lookbehind) - 1), line.decode('utf-8').rstrip()))
                     return True
         return False
 
@@ -433,7 +440,11 @@ class VersionConfig(object):
         self.replace = replace
 
     def _labels_for_format(self, serialize_format):
-        return (label for _, label, _, _ in Formatter().parse(serialize_format))
+        return (
+            label
+            for _, label, _, _ in Formatter().parse(serialize_format)
+            if label
+        )
 
     def order(self):
         # currently, order depends on the first given serialization format
@@ -597,8 +608,9 @@ def main(original_args=None):
     parser1 = argparse.ArgumentParser(add_help=False)
 
     parser1.add_argument(
-        '--config-file', default='.bumpversion.cfg', metavar='FILE',
-        help='Config file to read most of the variables from', required=False)
+        '--config-file', metavar='FILE',
+        default=argparse.SUPPRESS, required=False,
+        help='Config file to read most of the variables from (default: .bumpversion.cfg)')
 
     parser1.add_argument(
         '--verbose', action='count', default=0,
@@ -652,7 +664,17 @@ def main(original_args=None):
     config = RawConfigParser('')
     config.add_section('bumpversion')
 
-    config_file_exists = os.path.exists(known_args.config_file)
+    explicit_config = hasattr(known_args, 'config_file')
+
+    if explicit_config:
+        config_file = known_args.config_file
+    elif not os.path.exists('.bumpversion.cfg') and \
+            os.path.exists('setup.cfg'):
+        config_file = 'setup.cfg'
+    else:
+        config_file = '.bumpversion.cfg'
+
+    config_file_exists = os.path.exists(config_file)
 
     part_configs = {}
 
@@ -660,14 +682,14 @@ def main(original_args=None):
 
     if config_file_exists:
 
-        config.readfp(io.open(known_args.config_file, 'rt', encoding='utf-8'))
+        logger.info("Reading config file {}:".format(config_file))
+        logger.info(io.open(config_file, 'rt', encoding='utf-8').read())
+
+        config.readfp(io.open(config_file, 'rt', encoding='utf-8'))
 
         log_config = StringIO()
         config.write(log_config)
 
-        logger.info("Reading config file {}:".format(known_args.config_file))
-        logger.info(log_config.getvalue())
-
         if 'files' in dict(config.items("bumpversion")):
             warnings.warn(
                 "'files =' configuration is will be deprecated, please use [bumpversion:file:...]",
@@ -735,8 +757,8 @@ def main(original_args=None):
                 files.append(ConfiguredFile(filename, VersionConfig(**section_config)))
 
     else:
-        message = "Could not read config file at {}".format(known_args.config_file)
-        if known_args.config_file != parser1.get_default('config_file'):
+        message = "Could not read config file at {}".format(config_file)
+        if explicit_config:
             raise argparse.ArgumentTypeError(message)
         else:
             logger.info(message)
@@ -906,14 +928,14 @@ def main(original_args=None):
 
         logger.info("{} to config file {}:".format(
             "Would write" if not write_to_config_file else "Writing",
-            known_args.config_file,
+            config_file,
         ))
 
         config.write(new_config)
         logger.info(new_config.getvalue())
 
         if write_to_config_file:
-            with io.open(known_args.config_file, 'wb') as f:
+            with io.open(config_file, 'wb') as f:
                 f.write(new_config.getvalue().encode('utf-8'))
 
     except UnicodeEncodeError:
@@ -923,7 +945,7 @@ def main(original_args=None):
         )
 
     if config_file_exists:
-        commit_files.append(known_args.config_file)
+        commit_files.append(config_file)
 
     if not vcs:
         return
